==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/FunctionArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.message.FunctionArgument;
import io.ciera.tool.sql.ooaofooa.message.FunctionArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;

import java.util.Arrays;
import java.util.List;


public class FunctionArgumentSetImpl extends InstanceSet<FunctionArgumentSet,FunctionArgument> implements FunctionArgumentSet {

    // attributes
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( FunctionArgument functionargument : this ) functionargument.setArg_ID( ref_Arg_ID );
    }
    @Override
    public void setSParm_ID( UniqueId ref_SParm_ID ) throws XtumlException {
        for ( FunctionArgument functionargument : this ) functionargument.setSParm_ID( ref_SParm_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( FunctionArgument functionargument : this ) messageargumentset.add( functionargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public FunctionParameterSet R1016_is_represented_by_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( FunctionArgument functionargument : this ) functionparameterset.add( functionargument.R1016_is_represented_by_FunctionParameter() );
        return functionparameterset;
    }


    @Override
    public FunctionArgument nullElement() {
        return FunctionArgumentImpl.EMPTY_FUNCTIONARGUMENT;
    }

    @Override
    public FunctionArgumentSet emptySet() {
      return new FunctionArgumentSetImpl();
    }

    @Override
    public FunctionArgumentSet value() {
        return this;
    }

    @Override
    public List<FunctionArgument> elements() {
        return Arrays.asList(toArray(new FunctionArgument[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/FunctionArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.message.FunctionArgument;
import io.ciera.tool.sql.ooaofooa.message.FunctionArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class FunctionArgumentSetImpl extends InstanceSet<FunctionArgumentSet,FunctionArgument> implements FunctionArgumentSet {

    public FunctionArgumentSetImpl() {
    }

    public FunctionArgumentSetImpl(Comparator<? super FunctionArgument> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( FunctionArgument functionargument : this ) functionargument.setArg_ID( ref_Arg_ID );
    }
    @Override
    public void setSParm_ID( UniqueId ref_SParm_ID ) throws XtumlException {
        for ( FunctionArgument functionargument : this ) functionargument.setSParm_ID( ref_SParm_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( FunctionArgument functionargument : this ) messageargumentset.add( functionargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public FunctionParameterSet R1016_is_represented_by_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( FunctionArgument functionargument : this ) functionparameterset.add( functionargument.R1016_is_represented_by_FunctionParameter() );
        return functionparameterset;
    }


    @Override
    public FunctionArgument nullElement() {
        return FunctionArgumentImpl.EMPTY_FUNCTIONARGUMENT;
    }

    @Override
    public FunctionArgumentSet emptySet() {
      return new FunctionArgumentSetImpl();
    }

    @Override
    public FunctionArgumentSet emptySet(Comparator<? super FunctionArgument> comp) {
      return new FunctionArgumentSetImpl(comp);
    }

    @Override
    public FunctionArgumentSet value() {
        return this;
    }

    @Override
    public List<FunctionArgument> elements() {
        return Arrays.asList(toArray(new FunctionArgument[0]));
    }

}
